@@ -207,12 +207,10 @@ func (self *WorkingTreeHelper) promptToStageAllAndRetry(retry func() error) erro
 		Prompt: self.c.Tr.NoFilesStagedPrompt,
 		HandleConfirm: func() error {
 			self.c.LogAction(self.c.Tr.Actions.StageAllFiles)
-			if err := self.c.Git().WorkingTree.StageAll(); err != nil {
-				return err
-			}
-			if err := self.syncRefresh(); err != nil {
+			if err := self.c.Git().WorkingTree.StageAll(false); err != nil {
 				return err
 			}
+			self.syncRefresh()
 
 			return retry()
 		},
@@ -222,20 +220,20 @@ func (self *WorkingTreeHelper) promptToStageAllAndRetry(retry func() error) erro
 }
 
 // for when you need to refetch files before continuing an action. Runs synchronously.
-func (self *WorkingTreeHelper) syncRefresh() error {
-	return self.c.Refresh(types.RefreshOptions{Mode: types.SYNC, Scope: []types.RefreshableView{types.FILES}})
+func (self *WorkingTreeHelper) syncRefresh() {
+	self.c.Refresh(types.RefreshOptions{Mode: types.SYNC, Scope: []types.RefreshableView{types.FILES}})
 }
 
 func (self *WorkingTreeHelper) prepareFilesForCommit() error {
 	noStagedFiles := !self.AnyStagedFiles()
 	if noStagedFiles && self.c.UserConfig().Gui.SkipNoStagedFilesWarning {
 		self.c.LogAction(self.c.Tr.Actions.StageAllFiles)
-		err := self.c.Git().WorkingTree.StageAll()
+		err := self.c.Git().WorkingTree.StageAll(false)
 		if err != nil {
 			return err
 		}
 
-		return self.syncRefresh()
+		self.syncRefresh()
 	}
 
 	return nil
@@ -245,7 +243,7 @@ func (self *WorkingTreeHelper) commitPrefixConfigsForRepo() []config.CommitPrefi
 	cfg, ok := self.c.UserConfig().Git.CommitPrefixes[self.c.Git().RepoPaths.RepoName()]
 	if ok {
 		return append(cfg, self.c.UserConfig().Git.CommitPrefix...)
-	} else {
-		return self.c.UserConfig().Git.CommitPrefix
 	}
+
+	return self.c.UserConfig().Git.CommitPrefix
 }
