@@ -5,18 +5,18 @@ import (
 	"sync"
 
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
+	"github.com/jesseduffield/lazygit/pkg/common"
 	"github.com/jesseduffield/lazygit/pkg/gui/context/traits"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/samber/lo"
-	"github.com/sirupsen/logrus"
 )
 
 type ICommitFileTreeViewModel interface {
 	ICommitFileTree
 	types.IListCursor
 
-	GetRef() types.Ref
-	SetRef(types.Ref)
+	GetRef() models.Ref
+	SetRef(models.Ref)
 	GetRefRange() *types.RefRange // can be nil, in which case GetRef should be used
 	SetRefRange(*types.RefRange)  // should be set to nil when selection is not a range
 	GetCanRebase() bool
@@ -30,7 +30,7 @@ type CommitFileTreeViewModel struct {
 
 	// this is e.g. the commit for which we're viewing the files, if there is no
 	// range selection, or if the range selection can't be used for some reason
-	ref types.Ref
+	ref models.Ref
 
 	// this is a commit range for which we're viewing the files. Can be nil, in
 	// which case ref is used.
@@ -43,8 +43,8 @@ type CommitFileTreeViewModel struct {
 
 var _ ICommitFileTreeViewModel = &CommitFileTreeViewModel{}
 
-func NewCommitFileTreeViewModel(getFiles func() []*models.CommitFile, log *logrus.Entry, showTree bool) *CommitFileTreeViewModel {
-	fileTree := NewCommitFileTree(getFiles, log, showTree)
+func NewCommitFileTreeViewModel(getFiles func() []*models.CommitFile, common *common.Common, showTree bool) *CommitFileTreeViewModel {
+	fileTree := NewCommitFileTree(getFiles, common, showTree)
 	listCursor := traits.NewListCursor(fileTree.Len)
 	return &CommitFileTreeViewModel{
 		ICommitFileTree: fileTree,
@@ -55,11 +55,11 @@ func NewCommitFileTreeViewModel(getFiles func() []*models.CommitFile, log *logru
 	}
 }
 
-func (self *CommitFileTreeViewModel) GetRef() types.Ref {
+func (self *CommitFileTreeViewModel) GetRef() models.Ref {
 	return self.ref
 }
 
-func (self *CommitFileTreeViewModel) SetRef(ref types.Ref) {
+func (self *CommitFileTreeViewModel) SetRef(ref models.Ref) {
 	self.ref = ref
 }
 
@@ -148,12 +148,12 @@ func (self *CommitFileTreeViewModel) ToggleShowTree() {
 	if selectedNode == nil {
 		return
 	}
-	path := selectedNode.Path
+	path := selectedNode.path
 
 	if self.InTreeMode() {
 		self.ExpandToPath(path)
 	} else if len(selectedNode.Children) > 0 {
-		path = selectedNode.GetLeaves()[0].Path
+		path = selectedNode.GetLeaves()[0].path
 	}
 
 	index, found := self.GetIndexForPath(path)
@@ -170,7 +170,7 @@ func (self *CommitFileTreeViewModel) CollapseAll() {
 		return
 	}
 
-	topLevelPath := strings.Split(selectedNode.Path, "/")[0]
+	topLevelPath := strings.Split(selectedNode.path, "/")[0]
 	index, found := self.GetIndexForPath(topLevelPath)
 	if found {
 		self.SetSelectedLineIdx(index)
@@ -186,7 +186,7 @@ func (self *CommitFileTreeViewModel) ExpandAll() {
 		return
 	}
 
-	index, found := self.GetIndexForPath(selectedNode.Path)
+	index, found := self.GetIndexForPath(selectedNode.path)
 	if found {
 		self.SetSelectedLineIdx(index)
 	}
